#' NPP distribution tables
#' 
#' Probability distribution tables for net primary production (NPP) of the 
#' forest ecosystems in seven bioclimatic zones in Russia. A dataset contains 
#' distributions estimated with the landscape-ecosystem approach (LEA) and from 
#' the ensemble of dynamic global vegetation models (DGVMs).
#' 
#' @docType data
#' 
#' @format A data frame with 1131 rows and 17 variables
#' \itemize{
#'   \item npp: NPP values
#'   \item LEA_Tundra: LEA-based probability for the Tundra climatic zone
#'   \item LEA_Tundra_Northern_Taiga: LEA-based probability for the Forest 
#'         tundra and Northern Taiga climatic zone
#'   \item LEA_Middle_Taiga: LEA-based probability for the Middle taiga 
#'         climatic zone
#'   \item LEA_Southern_Taiga: LEA-based probability for the Southern taiga
#'         climatic zone
#'   \item LEA_Temperate: LEA-based probability for the Temperate climatic zone
#'   \item LEA_Steppe: LEA-based probability for the Steppe climatic zone
#'   \item LEA_Deserts: LEA-based probability for the Semi-deserts and deserts
#'         climatic zone
#'   \item LEA_Total: LEA-based probability taken over all climatic zones
#'   \item DGVM_Tundra: DGVM-based probability for the Tundra climatic zone
#'   \item DGVM_Tundra_Northern_Taiga: DGVM-based probability for the Forest 
#'         tundra and Northern Taiga climatic zone
#'   \item DGVM_Middle_Taiga: DGVM-based probability for the Middle taiga 
#'         climatic zone
#'   \item DGVM_Southern_Taiga: DGVM-based probability for the Southern taiga
#'         climatic zone
#'   \item DGVM_Temperate: DGVM-based probability for the Temperate climatic zone
#'   \item DGVM_Steppe: DGVM-based probability for the Steppe climatic zone
#'   \item DGVM_Deserts: DGVM-based probability for the Semi-deserts and deserts
#'         climatic zone
#'   \item DGVM_Total: DGVM-based probability taken over all climatic zones
#' }
#' @references Kryazhimskiy, A., Rovenskaya, E., Shvidenko, A., Gusti, M.
#' Shchepashchenko, D. & Veshchinskaya, V. (2015). Towards harmonizing 
#' competing models: Russian forests' net primary production case study.
#' Technological Forecasting & Social Change, 98: 245-254.
#' 
"forest_npp"

#' NPP distribution tables
#' 
#' Probability distribution tables for aggregated net primary production (NPP) 
#' of the forest ecosystems in seven bioclimatic zones in Russia.  A dataset 
#' contains distributions estimated with the landscape-ecosystem approach (LEA).
#' 
#' @docType data
#' 
#' @format A data frame with 15 rows and 9 variables
#' \itemize{
#'   \item npp: NPP values aggregated into size classes of 90 gC/m^2 per year
#'   \item LEA_Tundra: LEA-based probability for the Tundra climatic zone
#'   \item LEA_Tundra_Northern_Taiga: LEA-based probability for the Forest 
#'         tundra and Northern Taiga climatic zone
#'   \item LEA_Middle_Taiga: LEA-based probability for the Middle taiga 
#'         climatic zone
#'   \item LEA_Southern_Taiga: LEA-based probability for the Southern taiga
#'         climatic zone
#'   \item LEA_Temperate: LEA-based probability for the Temperate climatic zone
#'   \item LEA_Steppe: LEA-based probability for the Steppe climatic zone
#'   \item LEA_Deserts: LEA-based probability for the Semi-deserts and deserts
#'         climatic zone
#'   \item LEA_Total: LEA-based probability taken over all climatic zones
#' }
#' @references Kryazhimskiy, A., Rovenskaya, E., Shvidenko, A., Gusti, M.
#' Shchepashchenko, D. & Veshchinskaya, V. (2015). Towards harmonizing 
#' competing models: Russian forests' net primary production case study.
#' Technological Forecasting & Social Change, 98: 245-254.
#' 
"forest_npp90"
