#' Combination of prior distributions into an aggregated (synthetic) one. The 
#' package implements the posterior integration method [Kryazhimskiy, 2013]. 
#' For comparison, an implementation of simple averaging of the input 
#' distributions is added.
#' 
#' @title Overview of the modelIntegration package
#' @author Anna Shchiptsova, IIASA
#' @note A posteriori integration is understood as an improvement of data given 
#' by a priori probabilities. The approach is based on the concept of an a 
#' posteriori event in the product of probability spaces associated with a 
#' priori probabilities. The conditional probability on the product space that 
#' is specified by an a posteriori event (which reflects the fact that all
#' the prior stochastic estimates represent the same deterministic element)
#' determines in a natural way the probability on the set of initial elementary 
#' events; the latter is recognized as the result of a posteriori
#' integration of a priori models [Kryazhimskiy, 2016]. \cr
#' E.g., the probability of the true value to be equal \emph{z} is computed as 
#' \emph{p1[z]*p2[z]*...*pn[z]/P(E*)}, where \emph{p1...pn} are probabilities 
#' from \emph{x} and \emph{E*} denotes a posteriori event.
#' @seealso \code{\link{integrate}}
#' @references Kryazhimskiy, A.V. (2013). Posterior integration of independent 
#' stochastic estimates. IIASA Interim Report. IR-13-006. \cr
#' Kryazhimskiy, A.V. (2016). Posteriori integration of 
#' probabilities. Elementary theory. Theory of Probability and its Applications,
#' 60(1): 62-87.
#' @examples 
#' library(modelIntegration)
#' 
#' pdf1 <- c(0.75, 0.25)
#' pdf2 <- c(0.75, 0.25)
#' bins <- c(1, 2)
#' 
#' result <- integrate(bins, list(pdf1, pdf2))
#' 
#' summary(result)
#' product(result)
#' @docType package
#' @name modelIntegration
NULL
