#' Prints an object of the distribution_table class.
#' 
#' The print format matches a format for the data.frame class. The output 
#' contains discrete probability distributions of the sources and their
#' product. The column \emph{x} returns a random variable range. The 
#' \emph{Product} column has probabilities from the product distribution.
#' 
#' @title Print method
#' @param x an R object of the distribution_table class
#' @param ... other arguments passed to methods
#' @seealso \code{\link{product}}
#' @examples
#' # S3 method for class "distribution_table"
#' pdf1 <- c(0.75, 0.25)
#' pdf2 <- c(0.75, 0.25)
#' bins <- c(1, 2)
#' print(integrate(bins, list(pdf1, pdf2)))
#' @export
print.distribution_table <- function(x, ...) {
  print(cbind(x$pdfs, "Product" = product(x)[, 2]))
}
