#' Provides summary statistics of integrated combinations of the source
#' distributions.
#' 
#' Distributions are summarized by their mean and standard deviation. 
#' Source distributions are combined into the product and average integrated
#' distributions. 
#'    
#' @title Summary of integrated distributions
#' @param object an R object of the distribution_table class
#' @param ... other arguments passed to methods
#' @return A data frame with means and standard deviations. The columns 
#' "Product" and "Average" contain estimates for the corresponding integrated 
#' distributions.
#' @seealso \code{\link{statistics}}, \code{\link{product}}, 
#' \code{\link{average}}
#' @examples
#' # S3 method for class "distribution_table"
#' pdf1 <- c(0.75, 0.25)
#' pdf2 <- c(0.75, 0.25)
#' bins <- c(1, 2)
#' summary(integrate(bins, list(pdf1, pdf2)))
#' @export
summary.distribution_table <- function(object, ...) {
  data <- statistics(object)

  return (data[, tail(seq(1 : ncol(data)), 2)])
}
