# modelIntegration

Combination of prior distributions into an aggregated (synthetic) one. The package implements the posterior integration method [Kryazhimskiy, 2013]. For comparison, an implementation of simple averaging of the input distributions is added.

See the [Indroduction to the modelIntegration package](http://www.iiasa.ac.at/web/home/research/researchPrograms/AdvancedSystemsAnalysis/introductionModelIntegration.html)

## Install

Get the released version from 
http://www.iiasa.ac.at/web/home/research/researchPrograms/AdvancedSystemsAnalysis/modelIntegration-package.html

You can download either a Windows binary package 'modelIntegration_1.0.0.zip' or 
a bundled package 'modelIntegration_1.0.0.tar.gz'

On a Windows platform only:
install a  binary package
```R
install.packages(path_to_folder/modelIntegration_1.0.0.zip, repos = NULL)
```
where 'path_to_folder' will represent the full path to the local directory.

On all platforms:
install from a source distribution (build tools should be installed)
```R
install.packages(path_to_folder/modelIntegration_1.0.0.tar.gz, repos = NULL, type = "source")
```
where 'path_to_folder' will represent the full path to the local directory.
On Windows it will look something like this: "C:\\download folder\modelIntegration_1.0.0.tar.gz".
On UNIX it will look like this: "/home/download/modelIntegration_1.0.0.tar.gz".

## Usage
```R
library(modelIntegration)

example1 <- integrate(
    forest_npp[, 1], 
    pdfs = as.list(forest_npp[c("LEA_Tundra", "DGVM_Tundra")]))
    
example2 <- integrate(
    forest_npp90[, 1], 
    pdfs = as.list(forest_npp90["LEA_Tundra"]),
    cdfs = list("DGVM_Tundra" = function(x)(pnorm(x, mean = 202, sd = 52))))
    
summary(example1)
summary(example2)
```

## References
  [API Documentation] (http://www.iiasa.ac.at/web/home/research/researchPrograms/AdvancedSystemsAnalysis/manual.pdf)
  
  [1] Kryazhimskiy, A.V. (2013). Posterior integration of independent stochastic estimates. 
      IIASA Interim Report. IR-13-006.
  [2] Kryazhimskiy, A.V. (2016). Posteriori integration of probabilities. Elementary theory. 
      Theory of Probability and its Applications, 60(1): 62-87.
  [3] Kryazhimskiy, A., Rovenskaya, E., Shvidenko, A., Gusti, M. Shchepashchenko, D. & Veshchinskaya, V. (2015). Towards harmonizing competing models: Russian forests' net primary production case study.
      Technological Forecasting & Social Change, 98: 245-254.

## License

Licensed under [MIT](http://opensource.org/licenses/MIT)