context("Distribution_table class")

test_that("An instance of the distribution_table class should be created", {
  # Act
  comb <- distribution_table(
    vals = c(1, 2, 3),
    probabilities = list(
      p1 = c(0.1, 0.5, 0.4),
      p2 = c(0.2, 0.3, 0.5)))

  # Assert
  expect_that(comb, is_a("distribution_table"))
  expect_that(is.distribution_table(comb), is_true())
})

test_that("Type of constructor arguments should be checked", {
  # Assert
  expect_that(
    distribution_table(vals = list(),
                       probabilities = list(p1 = c(1), p2 = c(2))),
    throws_error("'vals': bad argument type"))
  expect_that(
    distribution_table(vals = 1,
                       probabilities = list(p1 = c(1), p2 = c(2))),
    throws_error("'vals': bad argument type"))
  expect_that(
    distribution_table(vals = c(1),
                       probabilities = list(p1 = c(1), p2 = c(2))),
    throws_error("'vals': bad argument type"))

  expect_that(
    distribution_table(vals = c(1, 2),
                       probabilities = list(p1 = list(), p2 = c(2, 2))),
    throws_error("'probabilities': bad argument type"))
  expect_that(
    distribution_table(vals = c(1, 2),
                       probabilities = list(p1 = 1, p2 = c(2, 2))),
    throws_error("'probabilities': bad argument type"))
  expect_that(
    distribution_table(vals = c(1, 2),
                       probabilities = list(p1 = c(1), p2 = c(2, 2))),
    throws_error("'probabilities': bad argument type"))

  expect_that(
    distribution_table(vals = c(1, 2),
                       probabilities = data.frame(p1 = c(1), p2 = c(2, 2))),
    throws_error("'probabilities': bad argument type"))
})

test_that("Constructor arguments should be vectors of the same length", {
  # Assert
  expect_that(
    distribution_table(vals = c(1, 2, 3),
                       probabilities = list(c(1, 2, 3), c(1, 2))),
    throws_error("Length of vector arguments should match"))
})
