context("Integration method")

test_that("'Table-based' distributions should be integrated", {
  # Arrange
  values <- forest_npp[, 1]
  zone1_pdfs <- as.list(
    forest_npp[c("LEA_Tundra", "DGVM_Tundra")])
  zone2_pdfs <- as.list(
    forest_npp[c("LEA_Tundra_Northern_Taiga", "DGVM_Tundra_Northern_Taiga")])
  zone3_pdfs <- as.list(
    forest_npp[c("LEA_Middle_Taiga", "DGVM_Middle_Taiga")])
  zone4_pdfs <- as.list(
    forest_npp[c("LEA_Southern_Taiga", "DGVM_Southern_Taiga")])
  zone5_pdfs <- as.list(
    forest_npp[c("LEA_Temperate", "DGVM_Temperate")])
  zone6_pdfs <- as.list(
    forest_npp[c("LEA_Steppe", "DGVM_Steppe")])
  zone7_pdfs <- as.list(
    forest_npp[c("LEA_Deserts", "DGVM_Deserts")])
  zones_pdfs <- as.list(
    forest_npp[c("LEA_Total", "DGVM_Total")])

  # Act
  result1 <- integrate(values, zone1_pdfs)
  result2 <- integrate(values, zone2_pdfs)
  result3 <- integrate(values, zone3_pdfs)
  result4 <- integrate(values, zone4_pdfs)
  result5 <- integrate(values, zone5_pdfs)
  result6 <- integrate(values, zone6_pdfs)
  result7 <- integrate(values, zone7_pdfs)
  result_all <- integrate(values, zones_pdfs)

  # Assert
  expect_that(
    all.equal(
      summary(result1),
      data.frame(Product = c(189.290348858845, 42.7850302316507),
                 Average = c(213.618420321799, 74.0616038698257),
                 row.names = c("mean", "std")),
      tolerance = 0.00001),
    is_true())

  expect_that(
    all.equal(
      summary(result2),
      data.frame(Product = c(244.5745932, 54.10022535),
                 Average = c(240.9406331, 77.80748385),
                 row.names = c("mean", "std")),
      tolerance = 0.00001),
    is_true())

  expect_that(
    all.equal(
      summary(result3),
      data.frame(Product = c(312.3343564, 61.56305434),
                 Average = c(296.207508, 100.857483),
                 row.names = c("mean", "std")),
      tolerance = 0.00001),
    is_true())

  expect_that(
    all.equal(
      summary(result4),
      data.frame(Product = c(437.997583, 76.41669531),
                 Average = c(419.7158964, 130.1258649),
                 row.names = c("mean", "std")),
      tolerance = 0.00001),
    is_true())

  expect_that(
    all.equal(
      summary(result5),
      data.frame(Product = c(491.5868501, 84.64792018),
                 Average = c(483.8401691, 157.2846854),
                 row.names = c("mean", "std")),
      tolerance = 0.00001),
    is_true())

  expect_that(
    all.equal(
      summary(result6),
      data.frame(Product = c(377.5373952, 71.68563931),
                 Average = c(394.8050619, 144.8180782),
                 row.names = c("mean", "std")),
      tolerance = 0.00001),
    is_true())

  expect_that(
    all.equal(
      summary(result7),
      data.frame(Product = c(403.1097863, 85.73745223),
                 Average = c(391.6700403, 144.6542541),
                 row.names = c("mean", "std")),
      tolerance = 0.00001),
    is_true())

  expect_that(
    all.equal(
      summary(result_all),
      data.frame(Product = c(326.9194897, 64.60802543),
                 Average = c(315.2172178, 116.2409784),
                 row.names = c("mean", "std")),
      tolerance = 0.00001),
    is_true())
})

test_that("Discrete and continuous priors should be integrated", {
  # Arrange
  values <- forest_npp90[, 1]

  pdf <- function(col_name)(as.list(forest_npp90[col_name]))
  cdf <- function(mean, sd)(function(x)(pnorm(x, mean = mean, sd = sd)))

  # Act
  result1 <- integrate(values,
                       pdf("LEA_Tundra"),
                       list("DGVM_Tundra" = cdf(202, 52)))
  result2 <- integrate(values,
                       pdf("LEA_Tundra_Northern_Taiga"),
                       list("DGVM_Tundra_Northern_Taiga" = cdf(269, 57)))
  result3 <- integrate(values,
                       pdf("LEA_Middle_Taiga"),
                       list("DGVM_Middle_Taiga" = cdf(335, 70)))
  result4 <- integrate(values,
                       pdf("LEA_Southern_Taiga"),
                       list("DGVM_Southern_Taiga" = cdf(449, 82)))
  result5 <- integrate(values,
                       pdf("LEA_Temperate"),
                       list("DGVM_Temperate" = cdf(513, 87)))
  result6 <- integrate(values,
                       pdf("LEA_Steppe"),
                       list("DGVM_Steppe" = cdf(390, 76)))
  result7 <- integrate(values,
                       pdf("LEA_Deserts"),
                       list("DGVM_Deserts" = cdf(423, 81)))
  result_all <- integrate(values,
                          pdf("LEA_Total"),
                          list("DGVM_Total" = cdf(348, 71)))

  # Assert
  expect_that(
    all.equal(
      summary(result1),
      data.frame(Product = c(183.7356204, 43.87124046),
                 Average = c(212.9200476, 79.16871977),
                 row.names = c("mean", "std")),
      tolerance = 0.00001),
    is_true())

  expect_that(
    all.equal(
      summary(result2),
      data.frame(Product = c(241.898887, 59.49116331),
                 Average = c(238.4595279, 84.71226882),
                 row.names = c("mean", "std")),
      tolerance = 0.00001),
    is_true())

  expect_that(
    all.equal(
      summary(result3),
      data.frame(Product = c(309.9850037, 66.38077032),
                 Average = c(296.3665605, 103.6270976),
                 row.names = c("mean", "std")),
      tolerance = 0.00001),
    is_true())

  expect_that(
    all.equal(
      summary(result4),
      data.frame(Product = c(436.5863399, 78.04555867),
                 Average = c(419.5291772, 133.2589279),
                 row.names = c("mean", "std")),
      tolerance = 0.00001),
    is_true())

  expect_that(
    all.equal(
      summary(result5),
      data.frame(Product = c(489.7805385, 85.7912758),
                 Average = c(484.5433777, 161.2456167),
                 row.names = c("mean", "std")),
      tolerance = 0.00001),
    is_true())

  expect_that(
    all.equal(
      summary(result6),
      data.frame(Product = c(379.5775344, 74.15462918),
                 Average = c(395.0143581, 148.6653506),
                 row.names = c("mean", "std")),
      tolerance = 0.00001),
    is_true())

  expect_that(
    all.equal(
      summary(result7),
      data.frame(Product = c(399.4125435, 84.82562693),
                 Average = c(393.6473287, 148.8995849),
                 row.names = c("mean", "std")),
      tolerance = 0.00001),
    is_true())

  expect_that(
    all.equal(
      summary(result_all),
      data.frame(Product = c(325.7916786, 69.36125126),
                 Average = c(314.8657407, 119.6913455),
                 row.names = c("mean", "std")),
      tolerance = 0.00001),
    is_true())
})

test_that("'Cdf-based' distributions should be integrated", {
  # Arrange
  cdf <- function(x)(punif(x, min = 0.5, max = 2.5))

  # Act
  result <- integrate(
    vals = c(1, 2),
    cdfs = list(cdf, cdf))

  # Assert
  expect_that(
    all.equal(
      summary(result),
      data.frame(Product = c(1.5, 0.5),
                 Average = c(1.5, 0.5),
                 row.names = c("mean", "std")),
      tolerance = 0.00001),
    is_true())
})
