context("Descriptive statistics")

test_that("Mean and std should be calculated for the source and
          integrated distributions", {
  # Act
  stats <- statistics(
    distribution_table(
      c(1, 2),
      list(c(0.5, 0.5), c(0.25, 0.75), c(0.25, 0.75))))

  # Assert
  expect_that(
    all.equal(
      stats,
      data.frame(P1 = c(1.5, 0.5),
                 P2 = c(7 / 4, sqrt(3) / 4),
                 P3 = c(7 / 4, sqrt(3) / 4),
                 Product = c(1.9, 0.3),
                 Average = c(5 / 3, sqrt(2) / 3),
                 row.names = c("mean", "std"))),
    is_true())
})

test_that("Distribution names should be taken from source distributions", {
  # Act
  stats <- statistics(
    distribution_table(
      c(1, 1),
      list("model1" = c(0.5, 0.5),
           "model2" = c(0.5, 0.5))))

  # Assert
  expect_that(
    all.equal(
      stats,
      data.frame(model1 = c(1, 0),
                 model2 = c(1, 0),
                 Product = c(1, 0),
                 Average = c(1, 0),
                 row.names = c("mean", "std"))),
    is_true())
})
